@@ -13,6 +13,8 @@ def rotation(x, p, angle):
 
 @njit
 def check_boundary(v0, v1, v2, v3, limit):
+    if (math.isnan(v0) or math.isnan(v1) or math.isnan(v2) or math.isnan(v3)):
+        return True
     return (v0 * v0 + v1 * v1 + v2 * v2 + v3 * v3) * 0.5 > limit
 
 
@@ -124,6 +126,14 @@ def henon_full_track(x, px, y, py, n_iterations, omega_x, omega_y):
             temp = (py[k - 1][j]
                     - 2 * x[k - 1][j] * y[k - 1][j])
             y[k][j], py[k][j] = rotation(y[k - 1][j], temp, omega_y[k - 1])
+
+            if (check_boundary(x[k][j], px[k][j], y[k][j], py[k][j], 1.0)):
+                x[k][j] = np.nan
+                px[k][j] = np.nan
+                y[k][j] = np.nan
+                py[k][j] = np.nan
+                n_iterations[j] = k - 1
+                break
             
     return x, px, y, py
 
